#include "server_env.hpp"
#include <boost/property_tree/ptree.hpp>
#include <boost/property_tree/ini_parser.hpp>
#include <boost/filesystem.hpp>
#include <cstdlib>

namespace dropshell {

server_env::server_env(const std::string& path) {
    // Construct the full path to _server.env
    boost::filesystem::path env_path = boost::filesystem::path(path) / "_server.env";
    
    // Check if file exists
    if (!boost::filesystem::exists(env_path)) {
        throw std::runtime_error("Server environment file not found: " + env_path.string());
    }

    try {
        // Read the INI file
        boost::property_tree::ptree pt;
        boost::property_tree::ini_parser::read_ini(env_path.string(), pt);

        // Store all variables
        for (const auto& section : pt) {
            for (const auto& key_value : section.second) {
                variables[key_value.first] = key_value.second.get_value<std::string>();
            }
        }

        // Verify required variables exist
        if (variables.find("SSH_HOST") == variables.end() ||
            variables.find("SSH_USER") == variables.end() ||
            variables.find("SSH_PORT") == variables.end()) {
            throw std::runtime_error("Missing required variables in server environment file");
        }
    } catch (const boost::property_tree::ini_parser_error& e) {
        throw std::runtime_error("Failed to parse server environment file: " + std::string(e.what()));
    }
}

std::string server_env::get_variable(const std::string& name) {
    auto it = variables.find(name);
    if (it == variables.end()) {
        return "";
    }

    std::string value = it->second;
    
    // Replace ${USER} with actual username
    const char* username = std::getenv("USER");
    if (username) {
        std::string user_var = "${USER}";
        size_t pos = value.find(user_var);
        if (pos != std::string::npos) {
            value.replace(pos, user_var.length(), username);
        }
    }

    return value;
}

std::string server_env::get_SSH_HOST() {
    return get_variable("SSH_HOST");
}

std::string server_env::get_SSH_USER() {
    return get_variable("SSH_USER");
}

std::string server_env::get_SSH_PORT() {
    return get_variable("SSH_PORT");
}

} // namespace dropshell 